require 'numru/netcdf'
include NumRu
s = 'tmp.nc'
f = NetCDF.create(s)
f.redef
d = f.def_dim('x',5)
v = f.def_var('x','sfloat',[d])
v2 = f.def_var('x2',NArray::SFLOAT,[d])
f.enddef
v.put([1,2,3,4,5])
p 'testing []= ...'
v[{0..3,2}]=[100,500]
v[1]=999
v[3..4]=[-99,-99]
v2.put(666)
v2[0..2]=777
f.close

f = NetCDF.open(s)
v = f.var('x')
p 'testing [] ...'
p v[{0..3,2}]
p v[1]
p v[3..4]
p v.rank
f.close
